@@ -24,14 +24,9 @@ from urllib import quote, unquote
 from urlparse import urljoin, urlsplit
 from HTMLParser import HTMLParser
 
-try:
-    from forgeimporters.base import ProjectExtractor
-    urlopen = ProjectExtractor.urlopen
-except ImportError:
-    try:
-        from allura.lib.helpers import urlopen
-    except ImportError:
-        from urllib2 import urlopen
+from forgeimporters.base import ProjectExtractor
+from forgeimporters.trac import TracURLValidator
+urlopen = ProjectExtractor.urlopen
 
 import html2text
 
@@ -101,19 +96,9 @@ class WikiExporter(object):
     }
 
     def __init__(self, base_url, options):
-        self.base_url = base_url
+        self.base_url = TracURLValidator().to_python(base_url)
         self.options = options
 
-        # remove extraneous /wiki/[PageName] as log as its near the end of the URL
-        base_url_parts = self.base_url.split('/')
-        try:
-            wiki_in_base_url = base_url_parts.index('wiki')
-        except ValueError:
-            wiki_in_base_url = None
-        if wiki_in_base_url >= len(base_url_parts) - 2:
-            self.base_url = '/'.join(base_url_parts[:wiki_in_base_url])
-        self.base_url = self.base_url.rstrip('/') + '/'
-
     def export(self, out):
         pages = []
         for title in self.page_list():
