@@ -16,7 +16,6 @@
 #       under the License.
 
 import json
-from optparse import OptionParser
 import logging
 
 from allura.lib.import_api import AlluraImportApiClient
@@ -50,7 +49,7 @@ def load_data(doc_file_name=None, optparser=None, options=None):
 
     import_options['user_map'] = user_map
 
-    cli = AlluraImportApiClient(options.base_url, options.api_key, options.secret_key, options.verbose)
+    cli = AlluraImportApiClient(options.base_url, options.token, options.verbose)
     doc_txt = open(doc_file_name).read()
 
     if options.wiki:
