@@ -37,11 +37,10 @@ class WikiFromTrac(ScriptTask):
             'Trac to allura wiki')
 
         parser.add_argument('trac_url', type=str, help='Trac URL')
-        parser.add_argument('-a', '--api-ticket', dest='api_key', help='API ticket')
-        parser.add_argument('-s', '--secret-key', dest='secret_key', help='Secret key')
+        parser.add_argument('-t', '--token', dest='token',
+                            help='OAuth bearer token (generate at /auth/oauth/)')
         parser.add_argument('-p', '--project', dest='project', help='Project to import to')
         parser.add_argument('-n', '--neighborhood', dest='neighborhood', help="URL prefix of destination neighborhood (e.g. 'p')", default='p')
-        parser.add_argument('-t', '--tracker', dest='tracker', help='Tracker to import to')
         parser.add_argument('-f', '--forum', dest='forum', help='Forum tool to import to')
         parser.add_argument('-w', '--wiki', dest='wiki', help='Wiki tool to import to')
         parser.add_argument('-u', '--base-url', dest='base_url', default='https://sourceforge.net', help='Base Allura (%(default)s for default)')
